@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: plot.c,v 1.104.2.4 2010/02/18 05:52:49 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: plot.c,v 1.104.2.8 2010/08/10 05:40:45 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - plot.c */
@@ -110,11 +110,9 @@ extern smg$create_key_table();
  * Only required by two files directly,
  * so I don't put this into a header file. -lh
  */
-#ifdef HAVE_LIBREADLINE
-# ifdef GNUPLOT_HISTORY
+#if defined(HAVE_LIBREADLINE) && !defined(MISSING_RL_TILDE_EXPANSION)
 #  include <readline/tilde.h>
-# endif
-extern int rl_complete_with_tilde_expansion;
+   extern int rl_complete_with_tilde_expansion;
 #endif
 
 /* BSD editline
@@ -345,6 +343,7 @@ main(int argc, char **argv)
 #if defined(HAVE_LIBEDITLINE)
     rl_getc_function = getc_wrapper;
 #endif
+
 #if defined(HAVE_LIBREADLINE) || defined(HAVE_LIBEDITLINE)
     using_history();
     /* T.Walter 1999-06-24: 'rl_readline_name' must be this fix name.
@@ -352,7 +351,7 @@ main(int argc, char **argv)
     rl_readline_name = "Gnuplot";
     rl_terminal_name = getenv("TERM");
 #endif
-#if defined(HAVE_LIBREADLINE)
+#if defined(HAVE_LIBREADLINE) && !defined(MISSING_RL_TILDE_EXPANSION)
     rl_complete_with_tilde_expansion = 1;
 #endif
 
@@ -578,7 +577,7 @@ main(int argc, char **argv)
 	/* come back here from int_error() */
 	if (interactive == FALSE)
 	    exit_status = EXIT_FAILURE;
-#ifdef HAVE_LIBREADLINE
+#ifdef HAVE_READLINE_RESET
 	else
 	{
 	    /* reset properly readline after a SIGINT+longjmp */
@@ -622,7 +621,7 @@ main(int argc, char **argv)
 	/* load filenames given as arguments */
 	while (--argc > 0) {
 	    ++argv;
-	    c_token = NO_CARET;	/* in case of file not found */
+	    c_token = 0;
 #ifdef _Windows
 	    if (stricmp(*argv, "-noend") == 0 || stricmp(*argv, "/noend") == 0
 	       	|| stricmp(*argv, "-persist") == 0)
@@ -633,13 +632,8 @@ main(int argc, char **argv)
 		FPRINTF((stderr,"'persist' command line option recognized\n"));
 
 	    } else if (strcmp(*argv, "-") == 0) {
-		/* DBT 10-7-98  go interactive if "-" on command line */
-
 		interactive = TRUE;
-		/* will this work on all platforms? */
-
 		while (!com_line());
-
 		interactive = FALSE;
 
 	    } else if (strcmp(*argv, "-e") == 0) {
@@ -650,8 +644,10 @@ main(int argc, char **argv)
 		}
 		do_string(*argv, FALSE);
 
-	    } else
+	    } else {
+		c_token = NO_CARET;	/* in case of file not found */
 		load_file(loadpath_fopen(*argv, "r"), gp_strdup(*argv), FALSE);
+	    }
 	}
 #ifdef _Windows
 	if (noend) {
