@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: term.c,v 1.184.2.9 2010/07/09 17:27:17 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: term.c,v 1.184.2.12 2011/01/11 01:08:05 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - term.c */
@@ -135,8 +135,8 @@ enum set_encoding_id encoding;
 /* table of encoding names, for output of the setting */
 const char *encoding_names[] = {
     "default", "iso_8859_1", "iso_8859_2", "iso_8859_9", "iso_8859_15",
-    "cp437", "cp850", "cp852", "cp1250", "cp1254", "koi8r", "koi8u", 
-    "utf8", NULL };
+    "cp437", "cp850", "cp852", "cp1250", "cp1251", "cp1254", 
+    "koi8r", "koi8u", "utf8", NULL };
 /* 'set encoding' options */
 const struct gen_table set_encoding_tbl[] =
 {
@@ -150,6 +150,7 @@ const struct gen_table set_encoding_tbl[] =
     { "cp850", S_ENC_CP850 },
     { "cp852", S_ENC_CP852 },
     { "cp1250", S_ENC_CP1250 },
+    { "cp1251", S_ENC_CP1251 },
     { "cp1254", S_ENC_CP1254 },
     { "koi8$r", S_ENC_KOI8_R },
     { "koi8$u", S_ENC_KOI8_U },
@@ -219,6 +220,8 @@ static void MOVE_null __PROTO((unsigned int, unsigned int));
 static void LINETYPE_null __PROTO((int));
 static void PUTTEXT_null __PROTO((unsigned int, unsigned int, const char *));
 
+static int strlen_tex __PROTO((const char *));
+
 /* Used by terminals and by shared routine parse_term_size() */
 typedef enum {
     PIXELS,
@@ -1797,7 +1800,7 @@ init_terminal()
    LINUX_setup has failed, also if we are logged in by network */
 #ifdef LINUXVGA
 	if (LINUX_graphics_allowed)
-#ifdef VGAGL
+#if defined(VGAGL) && defined (THREEDKIT)
 	    term_name = "vgagl";
 #else
 	    term_name = "linux";
@@ -2835,6 +2838,10 @@ estimate_strlen(char *text)
 {
 int len;
 
+    if ((term->flags & TERM_IS_LATEX))
+	len = strlen_tex(text);
+    else
+
 #ifdef GP_ENH_EST
     if (strchr(text,'\n') || (term->flags & TERM_ENHANCED_TEXT)) {
 	struct termentry *tsave = term;
@@ -3016,3 +3023,50 @@ lp_use_properties(struct lp_style_type *lp, int tag)
     lp->p_type = tag - 1;
 }
 
+/*
+ * Totally bogus estimate of TeX string lengths.
+ * Basically 
+ * - don't count anything inside square braces
+ * - count regexp \[a-zA-z]* as a single character
+ * - ignore characters {}$^_ 
+ */
+int
+strlen_tex(const char *str)
+{
+    const char *s = str;
+    int len = 0;
+
+    if (!strpbrk(s, "{}$[]\\")) {
+	len = strlen(s);
+	FPRINTF((stderr,"strlen_tex(\"%s\") = %d\n",s,len));
+	return len;
+    }
+
+    while (*s) {
+	switch (*s) {
+	case '[':
+		while (*s && *s != ']') s++;
+		s++;
+		break;
+	case '\\':
+		s++;
+		while (*s && isalpha(*s)) s++;
+		len++;
+		break;
+	case '{':
+	case '}':
+	case '$':
+	case '_':
+	case '^':
+		s++;
+		break;
+	default:
+		s++;
+		len++;
+	}
+    }
+
+
+    FPRINTF((stderr,"strlen_tex(\"%s\") = %d\n",str,len));
+    return len;
+}
