@@ -1,5 +1,5 @@
 /*
- * $Id: term_api.h,v 1.80.2.3 2009/09/13 17:43:41 sfeam Exp $
+ * $Id: term_api.h,v 1.80.2.5 2010/10/07 05:31:42 sfeam Exp $
  */
 
 /* GNUPLOT - term_api.h */
@@ -154,11 +154,7 @@ typedef struct t_image {
     TBOOLEAN fallback; /* true == don't use terminal-specific code */
 } t_image;
 
-/* values for the optional flags field - choose sensible defaults
- * these aren't really very sensible names - multiplot attributes
- * depend on whether stdout is redirected or not. Remember that
- * the default is 0. Thus most drivers can do multiplot only if
- * the output is redirected
+/* Values for the flags field of TERMENTRY
  */
 #define TERM_CAN_MULTIPLOT    1  /* tested if stdout not redirected */
 #define TERM_CANNOT_MULTIPLOT 2  /* tested if stdout is redirected  */
@@ -172,6 +168,7 @@ typedef struct t_image {
 #define TERM_ALPHA_CHANNEL  512  /* alpha channel transparency      */
 #define TERM_MONOCHROME    1024  /* term is running in mono mode    */
 #define TERM_LINEWIDTH     2048  /* support for set term linewidth  */
+#define TERM_IS_LATEX      8192  /* text uses TeX markup            */
 
 /* The terminal interface structure --- heart of the terminal layer.
  *
@@ -280,7 +277,7 @@ typedef struct TERMENTRY {
 
 enum set_encoding_id {
    S_ENC_DEFAULT, S_ENC_ISO8859_1, S_ENC_ISO8859_2, S_ENC_ISO8859_9, S_ENC_ISO8859_15,
-   S_ENC_CP437, S_ENC_CP850, S_ENC_CP852, S_ENC_CP1250, S_ENC_CP1254,
+   S_ENC_CP437, S_ENC_CP850, S_ENC_CP852, S_ENC_CP1250, S_ENC_CP1251, S_ENC_CP1254,
    S_ENC_KOI8_R, S_ENC_KOI8_U,
    S_ENC_UTF8,
    S_ENC_INVALID
